@@ -1,6 +1,7 @@
 // Predefined symbols and macros -*- C++ -*-
 
-// Copyright (C) 1997, 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
+// Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003
+// Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -34,10 +35,9 @@
 #include <bits/os_defines.h>
 
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCPP__ 20030422
+#define __GLIBCPP__ 20050223
 
-// This is necessary until GCC supports separate template
-// compilation.  
+// This is necessary until GCC supports separate template compilation.
 #define _GLIBCPP_NO_TEMPLATE_EXPORT 1
 
 // This is a hack around not having either pre-compiled headers or
@@ -49,6 +49,16 @@
 // by the compiler, but instead instantiated into the library binary.
 #define _GLIBCPP_FULLY_COMPLIANT_HEADERS 1
 
+// Allow use of the GNU syntax extension, "extern template." This
+// extension is fully documented in the g++ manual, but in a nutshell,
+// it inhibits all implicit instantiations and is used throughout the
+// library to avoid multiple weak definitions for required types that
+// are already explicitly instantiated in the library binary. This
+// substantially reduces the binary size of resulting executables.
+#ifndef _GLIBCPP_EXTERN_TEMPLATE
+#define _GLIBCPP_EXTERN_TEMPLATE 1
+#endif
+
 // To enable older, ARM-style iostreams and other anachronisms use this.
 //#define _GLIBCPP_DEPRECATED 1
 
@@ -77,6 +87,13 @@
 #error __USE_MALLOC should never be defined.  Read the release notes.
 #endif
 
+// Create a boolean flag to be used to determine if --fast-math is set.
+#ifdef __FAST_MATH__
+#define _GLIBCPP_FAST_MATH 1
+#else
+#define _GLIBCPP_FAST_MATH 0
+#endif
+
 // The remainder of the prewritten config is mostly automatic; all the
 // user hooks are listed above.
 
@@ -100,7 +117,7 @@
 /* #undef _GLIBCPP_USE_WCHAR_T */
 
 // Define if using setrlimit to limit memory usage during 'make check'.
-/* #undef _GLIBCPP_MEM_LIMITS */
+#define _GLIBCPP_MEM_LIMITS 1
 
 // Define to use concept checking code from the boost libraries.
 /* #undef _GLIBCPP_CONCEPT_CHECKS */
@@ -122,8 +139,20 @@
 // Define if gthr-default.h exists (meaning that threading support is enabled).
 /* #undef _GLIBCPP_HAVE_GTHR_DEFAULT */
 
+// Define if drand48 exists.
+#define _GLIBCPP_HAVE_DRAND48 1
+
+// Define if getpagesize exists.
+#define _GLIBCPP_HAVE_GETPAGESIZE 1
+
+// Define if setenv exists.
+#define _GLIBCPP_HAVE_SETENV 1
+
+// Define if sigsetjmp exists.
+#define _GLIBCPP_HAVE_SIGSETJMP 1
+
 // Define if mbstate_t exists in wchar.h.
-/* #undef _GLIBCPP_HAVE_MBSTATE_T */
+#define _GLIBCPP_HAVE_MBSTATE_T 1
 
 // Define if you have the modff function.
 #define _GLIBCPP_HAVE_MODFF 1
@@ -150,13 +179,13 @@
 #define _GLIBCPP_HAVE___BUILTIN_LABS 1
 
 // Define if the compiler/host combination has __builtin_cos
-/* #undef _GLIBCPP_HAVE___BUILTIN_COS */
+#define _GLIBCPP_HAVE___BUILTIN_COS 1
 
 // Define if the compiler/host combination has __builtin_cosf
-/* #undef _GLIBCPP_HAVE___BUILTIN_COSF */
+#define _GLIBCPP_HAVE___BUILTIN_COSF 1
 
 // Define if the compiler/host combination has __builtin_cosl
-/* #undef _GLIBCPP_HAVE___BUILTIN_COSL */
+#define _GLIBCPP_HAVE___BUILTIN_COSL 1
 
 // Define if the compiler/host combination has __builtin_fabs
 #define _GLIBCPP_HAVE___BUILTIN_FABS 1
@@ -168,13 +197,13 @@
 #define _GLIBCPP_HAVE___BUILTIN_FABSL 1
 
 // Define if the compiler/host combination has __builtin_sin
-/* #undef _GLIBCPP_HAVE___BUILTIN_SIN */
+#define _GLIBCPP_HAVE___BUILTIN_SIN 1
 
 // Define if the compiler/host combination has __builtin_sinf
-/* #undef _GLIBCPP_HAVE___BUILTIN_SINF */
+#define _GLIBCPP_HAVE___BUILTIN_SINF 1
 
 // Define if the compiler/host combination has __builtin_sinl
-/* #undef _GLIBCPP_HAVE___BUILTIN_SINL */
+#define _GLIBCPP_HAVE___BUILTIN_SINL 1
 
 // Define if the compiler/host combination has __builtin_sqrt
 /* #undef _GLIBCPP_HAVE___BUILTIN_SQRT */
@@ -185,6 +214,15 @@
 // Define if the compiler/host combination has __builtin_sqrtl
 /* #undef _GLIBCPP_HAVE___BUILTIN_SQRTL */
 
+// Define if poll is available in <poll.h>.
+#define _GLIBCPP_HAVE_POLL 1
+
+// Define if S_ISREG (Posix) is available in <sys/stat.h>.
+#define _GLIBCPP_HAVE_S_ISREG 1
+
+// Define if S_IFREG is available in <sys/stat.h>.
+/* #undef _GLIBCPP_HAVE_S_IFREG */
+
 // Define if LC_MESSAGES is available in <locale.h>.
 #define _GLIBCPP_HAVE_LC_MESSAGES 1
 
@@ -411,7 +449,7 @@
 /* #undef _GLIBCPP_HAVE_ATANL */
 
 /* Define if you have the btowc function.  */
-/* #undef _GLIBCPP_HAVE_BTOWC */
+#define _GLIBCPP_HAVE_BTOWC 1
 
 /* Define if you have the ceilf function.  */
 #define _GLIBCPP_HAVE_CEILF 1
@@ -456,10 +494,10 @@
 /* #undef _GLIBCPP_HAVE_FABSL */
 
 /* Define if you have the fgetwc function.  */
-/* #undef _GLIBCPP_HAVE_FGETWC */
+#define _GLIBCPP_HAVE_FGETWC 1
 
 /* Define if you have the fgetws function.  */
-/* #undef _GLIBCPP_HAVE_FGETWS */
+#define _GLIBCPP_HAVE_FGETWS 1
 
 /* Define if you have the finite function.  */
 #define _GLIBCPP_HAVE_FINITE 1
@@ -486,10 +524,10 @@
 /* #undef _GLIBCPP_HAVE_FPCLASS */
 
 /* Define if you have the fputwc function.  */
-/* #undef _GLIBCPP_HAVE_FPUTWC */
+#define _GLIBCPP_HAVE_FPUTWC 1
 
 /* Define if you have the fputws function.  */
-/* #undef _GLIBCPP_HAVE_FPUTWS */
+#define _GLIBCPP_HAVE_FPUTWS 1
 
 /* Define if you have the frexpf function.  */
 #define _GLIBCPP_HAVE_FREXPF 1
@@ -498,7 +536,7 @@
 /* #undef _GLIBCPP_HAVE_FREXPL */
 
 /* Define if you have the fwide function.  */
-/* #undef _GLIBCPP_HAVE_FWIDE */
+#define _GLIBCPP_HAVE_FWIDE 1
 
 /* Define if you have the fwprintf function.  */
 /* #undef _GLIBCPP_HAVE_FWPRINTF */
@@ -510,10 +548,10 @@
 #define _GLIBCPP_HAVE_GETPAGESIZE 1
 
 /* Define if you have the getwc function.  */
-/* #undef _GLIBCPP_HAVE_GETWC */
+#define _GLIBCPP_HAVE_GETWC 1
 
 /* Define if you have the getwchar function.  */
-/* #undef _GLIBCPP_HAVE_GETWCHAR */
+#define _GLIBCPP_HAVE_GETWCHAR 1
 
 /* Define if you have the hypot function.  */
 #define _GLIBCPP_HAVE_HYPOT 1
@@ -573,16 +611,16 @@
 /* #undef _GLIBCPP_HAVE_LOGL */
 
 /* Define if you have the mbrlen function.  */
-/* #undef _GLIBCPP_HAVE_MBRLEN */
+#define _GLIBCPP_HAVE_MBRLEN 1
 
 /* Define if you have the mbrtowc function.  */
-/* #undef _GLIBCPP_HAVE_MBRTOWC */
+#define _GLIBCPP_HAVE_MBRTOWC 1
 
 /* Define if you have the mbsinit function.  */
-/* #undef _GLIBCPP_HAVE_MBSINIT */
+#define _GLIBCPP_HAVE_MBSINIT 1
 
 /* Define if you have the mbsrtowcs function.  */
-/* #undef _GLIBCPP_HAVE_MBSRTOWCS */
+#define _GLIBCPP_HAVE_MBSRTOWCS 1
 
 /* Define if you have the modff function.  */
 #define _GLIBCPP_HAVE_MODFF 1
@@ -594,7 +632,7 @@
 /* #undef _GLIBCPP_HAVE_NAN */
 
 /* Define if you have the nl_langinfo function.  */
-/* #undef _GLIBCPP_HAVE_NL_LANGINFO */
+#define _GLIBCPP_HAVE_NL_LANGINFO 1
 
 /* Define if you have the powf function.  */
 #define _GLIBCPP_HAVE_POWF 1
@@ -603,10 +641,10 @@
 /* #undef _GLIBCPP_HAVE_POWL */
 
 /* Define if you have the putwc function.  */
-/* #undef _GLIBCPP_HAVE_PUTWC */
+#define _GLIBCPP_HAVE_PUTWC 1
 
 /* Define if you have the putwchar function.  */
-/* #undef _GLIBCPP_HAVE_PUTWCHAR */
+#define _GLIBCPP_HAVE_PUTWCHAR 1
 
 /* Define if you have the qfpclass function.  */
 /* #undef _GLIBCPP_HAVE_QFPCLASS */
@@ -666,7 +704,7 @@
 /* #undef _GLIBCPP_HAVE_TANL */
 
 /* Define if you have the ungetwc function.  */
-/* #undef _GLIBCPP_HAVE_UNGETWC */
+#define _GLIBCPP_HAVE_UNGETWC 1
 
 /* Define if you have the vfwprintf function.  */
 /* #undef _GLIBCPP_HAVE_VFWPRINTF */
@@ -687,91 +725,91 @@
 /* #undef _GLIBCPP_HAVE_VWSCANF */
 
 /* Define if you have the wcrtomb function.  */
-/* #undef _GLIBCPP_HAVE_WCRTOMB */
+#define _GLIBCPP_HAVE_WCRTOMB 1
 
 /* Define if you have the wcscat function.  */
-/* #undef _GLIBCPP_HAVE_WCSCAT */
+#define _GLIBCPP_HAVE_WCSCAT 1
 
 /* Define if you have the wcschr function.  */
-/* #undef _GLIBCPP_HAVE_WCSCHR */
+#define _GLIBCPP_HAVE_WCSCHR 1
 
 /* Define if you have the wcscmp function.  */
-/* #undef _GLIBCPP_HAVE_WCSCMP */
+#define _GLIBCPP_HAVE_WCSCMP 1
 
 /* Define if you have the wcscoll function.  */
-/* #undef _GLIBCPP_HAVE_WCSCOLL */
+#define _GLIBCPP_HAVE_WCSCOLL 1
 
 /* Define if you have the wcscpy function.  */
-/* #undef _GLIBCPP_HAVE_WCSCPY */
+#define _GLIBCPP_HAVE_WCSCPY 1
 
 /* Define if you have the wcscspn function.  */
-/* #undef _GLIBCPP_HAVE_WCSCSPN */
+#define _GLIBCPP_HAVE_WCSCSPN 1
 
 /* Define if you have the wcsftime function.  */
 /* #undef _GLIBCPP_HAVE_WCSFTIME */
 
 /* Define if you have the wcslen function.  */
-/* #undef _GLIBCPP_HAVE_WCSLEN */
+#define _GLIBCPP_HAVE_WCSLEN 1
 
 /* Define if you have the wcsncat function.  */
-/* #undef _GLIBCPP_HAVE_WCSNCAT */
+#define _GLIBCPP_HAVE_WCSNCAT 1
 
 /* Define if you have the wcsncmp function.  */
-/* #undef _GLIBCPP_HAVE_WCSNCMP */
+#define _GLIBCPP_HAVE_WCSNCMP 1
 
 /* Define if you have the wcsncpy function.  */
-/* #undef _GLIBCPP_HAVE_WCSNCPY */
+#define _GLIBCPP_HAVE_WCSNCPY 1
 
 /* Define if you have the wcspbrk function.  */
-/* #undef _GLIBCPP_HAVE_WCSPBRK */
+#define _GLIBCPP_HAVE_WCSPBRK 1
 
 /* Define if you have the wcsrchr function.  */
-/* #undef _GLIBCPP_HAVE_WCSRCHR */
+#define _GLIBCPP_HAVE_WCSRCHR 1
 
 /* Define if you have the wcsrtombs function.  */
-/* #undef _GLIBCPP_HAVE_WCSRTOMBS */
+#define _GLIBCPP_HAVE_WCSRTOMBS 1
 
 /* Define if you have the wcsspn function.  */
-/* #undef _GLIBCPP_HAVE_WCSSPN */
+#define _GLIBCPP_HAVE_WCSSPN 1
 
 /* Define if you have the wcsstr function.  */
-/* #undef _GLIBCPP_HAVE_WCSSTR */
+#define _GLIBCPP_HAVE_WCSSTR 1
 
 /* Define if you have the wcstod function.  */
-/* #undef _GLIBCPP_HAVE_WCSTOD */
+#define _GLIBCPP_HAVE_WCSTOD 1
 
 /* Define if you have the wcstof function.  */
 /* #undef _GLIBCPP_HAVE_WCSTOF */
 
 /* Define if you have the wcstok function.  */
-/* #undef _GLIBCPP_HAVE_WCSTOK */
+#define _GLIBCPP_HAVE_WCSTOK 1
 
 /* Define if you have the wcstol function.  */
-/* #undef _GLIBCPP_HAVE_WCSTOL */
+#define _GLIBCPP_HAVE_WCSTOL 1
 
 /* Define if you have the wcstoul function.  */
-/* #undef _GLIBCPP_HAVE_WCSTOUL */
+#define _GLIBCPP_HAVE_WCSTOUL 1
 
 /* Define if you have the wcsxfrm function.  */
-/* #undef _GLIBCPP_HAVE_WCSXFRM */
+#define _GLIBCPP_HAVE_WCSXFRM 1
 
 /* Define if you have the wctob function.  */
-/* #undef _GLIBCPP_HAVE_WCTOB */
+#define _GLIBCPP_HAVE_WCTOB 1
 
 /* Define if you have the wmemchr function.  */
-/* #undef _GLIBCPP_HAVE_WMEMCHR */
+#define _GLIBCPP_HAVE_WMEMCHR 1
 
 /* Define if you have the wmemcmp function.  */
-/* #undef _GLIBCPP_HAVE_WMEMCMP */
+#define _GLIBCPP_HAVE_WMEMCMP 1
 
 /* Define if you have the wmemcpy function.  */
-/* #undef _GLIBCPP_HAVE_WMEMCPY */
+#define _GLIBCPP_HAVE_WMEMCPY 1
 
 /* Define if you have the wmemmove function.  */
-/* #undef _GLIBCPP_HAVE_WMEMMOVE */
+#define _GLIBCPP_HAVE_WMEMMOVE 1
 
 /* Define if you have the wmemset function.  */
-/* #undef _GLIBCPP_HAVE_WMEMSET */
+#define _GLIBCPP_HAVE_WMEMSET 1
 
 /* Define if you have the wprintf function.  */
 /* #undef _GLIBCPP_HAVE_WPRINTF */
@@ -815,6 +853,12 @@
 /* Define if you have the <string.h> header file.  */
 #define _GLIBCPP_HAVE_STRING_H 1
 
+/* Define if you have the <sys/filio.h> header file.  */
+#define _GLIBCPP_HAVE_SYS_FILIO_H 1
+
+/* Define if you have the <sys/ioctl.h> header file.  */
+#define _GLIBCPP_HAVE_SYS_IOCTL_H 1
+
 /* Define if you have the <sys/isa_defs.h> header file.  */
 /* #undef _GLIBCPP_HAVE_SYS_ISA_DEFS_H */
 
@@ -827,6 +871,9 @@
 /* Define if you have the <sys/stat.h> header file.  */
 #define _GLIBCPP_HAVE_SYS_STAT_H 1
 
+/* Define if you have the <sys/time.h> header file.  */
+#define _GLIBCPP_HAVE_SYS_TIME_H 1
+
 /* Define if you have the <sys/types.h> header file.  */
 #define _GLIBCPP_HAVE_SYS_TYPES_H 1
 
@@ -834,10 +881,10 @@
 #define _GLIBCPP_HAVE_UNISTD_H 1
 
 /* Define if you have the <wchar.h> header file.  */
-/* #undef _GLIBCPP_HAVE_WCHAR_H */
+#define _GLIBCPP_HAVE_WCHAR_H 1
 
 /* Define if you have the <wctype.h> header file.  */
-/* #undef _GLIBCPP_HAVE_WCTYPE_H */
+#define _GLIBCPP_HAVE_WCTYPE_H 1
 
 /* Define if you have the m library (-lm).  */
 #define _GLIBCPP_HAVE_LIBM 1
@@ -846,7 +893,7 @@
 #define _GLIBCPP_PACKAGE "libstdc++"
 
 /* Version number of package */
-#define _GLIBCPP_VERSION "3.2.3"
+#define _GLIBCPP_VERSION "3.3.6"
 
 /* Define if the compiler is configured for setjmp/longjmp exceptions. */
 /* #undef _GLIBCPP_SJLJ_EXCEPTIONS */
@@ -855,10 +902,10 @@
 #define _GLIBCPP_HAVE_SIGSETJMP 1
 
 /* Only used in build directory testsuite_hooks.h. */
-#define _GLIBCPP_HAVE_MEMLIMIT_DATA 0
+#define _GLIBCPP_HAVE_MEMLIMIT_DATA 1
 
 /* Only used in build directory testsuite_hooks.h. */
-#define _GLIBCPP_HAVE_MEMLIMIT_RSS 0
+#define _GLIBCPP_HAVE_MEMLIMIT_RSS 1
 
 /* Only used in build directory testsuite_hooks.h. */
 #define _GLIBCPP_HAVE_MEMLIMIT_VMEM 0
