@@ -35,7 +35,7 @@
 #include <bits/os_defines.h>
 
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCPP__ 20050503
+#define __GLIBCPP__ 20050223
 
 // This is necessary until GCC supports separate template compilation.
 #define _GLIBCPP_NO_TEMPLATE_EXPORT 1
@@ -152,7 +152,7 @@
 #define _GLIBCPP_HAVE_SIGSETJMP 1
 
 // Define if mbstate_t exists in wchar.h.
-#define _GLIBCPP_HAVE_MBSTATE_T 1
+/* #undef _GLIBCPP_HAVE_MBSTATE_T */
 
 // Define if you have the modff function.
 #define _GLIBCPP_HAVE_MODFF 1
@@ -227,10 +227,10 @@
 #define _GLIBCPP_HAVE_LC_MESSAGES 1
 
 /* Define if you have the __signbit function.  */
-#define _GLIBCPP_HAVE___SIGNBIT 1
+/* #undef _GLIBCPP_HAVE___SIGNBIT */
 
 /* Define if you have the __signbitf function.  */
-#define _GLIBCPP_HAVE___SIGNBITF 1
+/* #undef _GLIBCPP_HAVE___SIGNBITF */
 
 /* Define if you have the __signbitl function.  */
 /* #undef _GLIBCPP_HAVE___SIGNBITL */
@@ -449,7 +449,7 @@
 /* #undef _GLIBCPP_HAVE_ATANL */
 
 /* Define if you have the btowc function.  */
-#define _GLIBCPP_HAVE_BTOWC 1
+/* #undef _GLIBCPP_HAVE_BTOWC */
 
 /* Define if you have the ceilf function.  */
 #define _GLIBCPP_HAVE_CEILF 1
@@ -494,10 +494,10 @@
 /* #undef _GLIBCPP_HAVE_FABSL */
 
 /* Define if you have the fgetwc function.  */
-#define _GLIBCPP_HAVE_FGETWC 1
+/* #undef _GLIBCPP_HAVE_FGETWC */
 
 /* Define if you have the fgetws function.  */
-#define _GLIBCPP_HAVE_FGETWS 1
+/* #undef _GLIBCPP_HAVE_FGETWS */
 
 /* Define if you have the finite function.  */
 #define _GLIBCPP_HAVE_FINITE 1
@@ -524,10 +524,10 @@
 /* #undef _GLIBCPP_HAVE_FPCLASS */
 
 /* Define if you have the fputwc function.  */
-#define _GLIBCPP_HAVE_FPUTWC 1
+/* #undef _GLIBCPP_HAVE_FPUTWC */
 
 /* Define if you have the fputws function.  */
-#define _GLIBCPP_HAVE_FPUTWS 1
+/* #undef _GLIBCPP_HAVE_FPUTWS */
 
 /* Define if you have the frexpf function.  */
 #define _GLIBCPP_HAVE_FREXPF 1
@@ -536,7 +536,7 @@
 /* #undef _GLIBCPP_HAVE_FREXPL */
 
 /* Define if you have the fwide function.  */
-#define _GLIBCPP_HAVE_FWIDE 1
+/* #undef _GLIBCPP_HAVE_FWIDE */
 
 /* Define if you have the fwprintf function.  */
 /* #undef _GLIBCPP_HAVE_FWPRINTF */
@@ -548,10 +548,10 @@
 #define _GLIBCPP_HAVE_GETPAGESIZE 1
 
 /* Define if you have the getwc function.  */
-#define _GLIBCPP_HAVE_GETWC 1
+/* #undef _GLIBCPP_HAVE_GETWC */
 
 /* Define if you have the getwchar function.  */
-#define _GLIBCPP_HAVE_GETWCHAR 1
+/* #undef _GLIBCPP_HAVE_GETWCHAR */
 
 /* Define if you have the hypot function.  */
 #define _GLIBCPP_HAVE_HYPOT 1
@@ -575,7 +575,7 @@
 #define _GLIBCPP_HAVE_ISATTY 1
 
 /* Define if you have the isinf function.  */
-/* #undef _GLIBCPP_HAVE_ISINF */
+#define _GLIBCPP_HAVE_ISINF 1
 
 /* Define if you have the isinff function.  */
 #define _GLIBCPP_HAVE_ISINFF 1
@@ -584,7 +584,7 @@
 /* #undef _GLIBCPP_HAVE_ISINFL */
 
 /* Define if you have the isnan function.  */
-/* #undef _GLIBCPP_HAVE_ISNAN */
+#define _GLIBCPP_HAVE_ISNAN 1
 
 /* Define if you have the isnanf function.  */
 #define _GLIBCPP_HAVE_ISNANF 1
@@ -611,16 +611,16 @@
 /* #undef _GLIBCPP_HAVE_LOGL */
 
 /* Define if you have the mbrlen function.  */
-#define _GLIBCPP_HAVE_MBRLEN 1
+/* #undef _GLIBCPP_HAVE_MBRLEN */
 
 /* Define if you have the mbrtowc function.  */
-#define _GLIBCPP_HAVE_MBRTOWC 1
+/* #undef _GLIBCPP_HAVE_MBRTOWC */
 
 /* Define if you have the mbsinit function.  */
-#define _GLIBCPP_HAVE_MBSINIT 1
+/* #undef _GLIBCPP_HAVE_MBSINIT */
 
 /* Define if you have the mbsrtowcs function.  */
-#define _GLIBCPP_HAVE_MBSRTOWCS 1
+/* #undef _GLIBCPP_HAVE_MBSRTOWCS */
 
 /* Define if you have the modff function.  */
 #define _GLIBCPP_HAVE_MODFF 1
@@ -629,10 +629,10 @@
 /* #undef _GLIBCPP_HAVE_MODFL */
 
 /* Define if you have the nan function.  */
-#define _GLIBCPP_HAVE_NAN 1
+/* #undef _GLIBCPP_HAVE_NAN */
 
 /* Define if you have the nl_langinfo function.  */
-#define _GLIBCPP_HAVE_NL_LANGINFO 1
+/* #undef _GLIBCPP_HAVE_NL_LANGINFO */
 
 /* Define if you have the powf function.  */
 #define _GLIBCPP_HAVE_POWF 1
@@ -641,10 +641,10 @@
 /* #undef _GLIBCPP_HAVE_POWL */
 
 /* Define if you have the putwc function.  */
-#define _GLIBCPP_HAVE_PUTWC 1
+/* #undef _GLIBCPP_HAVE_PUTWC */
 
 /* Define if you have the putwchar function.  */
-#define _GLIBCPP_HAVE_PUTWCHAR 1
+/* #undef _GLIBCPP_HAVE_PUTWCHAR */
 
 /* Define if you have the qfpclass function.  */
 /* #undef _GLIBCPP_HAVE_QFPCLASS */
@@ -680,7 +680,7 @@
 /* #undef _GLIBCPP_HAVE_SQRTL */
 
 /* Define if you have the strtof function.  */
-#define _GLIBCPP_HAVE_STRTOF 1
+/* #undef _GLIBCPP_HAVE_STRTOF */
 
 /* Define if you have the strtold function.  */
 /* #undef _GLIBCPP_HAVE_STRTOLD */
@@ -704,7 +704,7 @@
 /* #undef _GLIBCPP_HAVE_TANL */
 
 /* Define if you have the ungetwc function.  */
-#define _GLIBCPP_HAVE_UNGETWC 1
+/* #undef _GLIBCPP_HAVE_UNGETWC */
 
 /* Define if you have the vfwprintf function.  */
 /* #undef _GLIBCPP_HAVE_VFWPRINTF */
@@ -725,91 +725,91 @@
 /* #undef _GLIBCPP_HAVE_VWSCANF */
 
 /* Define if you have the wcrtomb function.  */
-#define _GLIBCPP_HAVE_WCRTOMB 1
+/* #undef _GLIBCPP_HAVE_WCRTOMB */
 
 /* Define if you have the wcscat function.  */
-#define _GLIBCPP_HAVE_WCSCAT 1
+/* #undef _GLIBCPP_HAVE_WCSCAT */
 
 /* Define if you have the wcschr function.  */
-#define _GLIBCPP_HAVE_WCSCHR 1
+/* #undef _GLIBCPP_HAVE_WCSCHR */
 
 /* Define if you have the wcscmp function.  */
-#define _GLIBCPP_HAVE_WCSCMP 1
+/* #undef _GLIBCPP_HAVE_WCSCMP */
 
 /* Define if you have the wcscoll function.  */
-#define _GLIBCPP_HAVE_WCSCOLL 1
+/* #undef _GLIBCPP_HAVE_WCSCOLL */
 
 /* Define if you have the wcscpy function.  */
-#define _GLIBCPP_HAVE_WCSCPY 1
+/* #undef _GLIBCPP_HAVE_WCSCPY */
 
 /* Define if you have the wcscspn function.  */
-#define _GLIBCPP_HAVE_WCSCSPN 1
+/* #undef _GLIBCPP_HAVE_WCSCSPN */
 
 /* Define if you have the wcsftime function.  */
 /* #undef _GLIBCPP_HAVE_WCSFTIME */
 
 /* Define if you have the wcslen function.  */
-#define _GLIBCPP_HAVE_WCSLEN 1
+/* #undef _GLIBCPP_HAVE_WCSLEN */
 
 /* Define if you have the wcsncat function.  */
-#define _GLIBCPP_HAVE_WCSNCAT 1
+/* #undef _GLIBCPP_HAVE_WCSNCAT */
 
 /* Define if you have the wcsncmp function.  */
-#define _GLIBCPP_HAVE_WCSNCMP 1
+/* #undef _GLIBCPP_HAVE_WCSNCMP */
 
 /* Define if you have the wcsncpy function.  */
-#define _GLIBCPP_HAVE_WCSNCPY 1
+/* #undef _GLIBCPP_HAVE_WCSNCPY */
 
 /* Define if you have the wcspbrk function.  */
-#define _GLIBCPP_HAVE_WCSPBRK 1
+/* #undef _GLIBCPP_HAVE_WCSPBRK */
 
 /* Define if you have the wcsrchr function.  */
-#define _GLIBCPP_HAVE_WCSRCHR 1
+/* #undef _GLIBCPP_HAVE_WCSRCHR */
 
 /* Define if you have the wcsrtombs function.  */
-#define _GLIBCPP_HAVE_WCSRTOMBS 1
+/* #undef _GLIBCPP_HAVE_WCSRTOMBS */
 
 /* Define if you have the wcsspn function.  */
-#define _GLIBCPP_HAVE_WCSSPN 1
+/* #undef _GLIBCPP_HAVE_WCSSPN */
 
 /* Define if you have the wcsstr function.  */
-#define _GLIBCPP_HAVE_WCSSTR 1
+/* #undef _GLIBCPP_HAVE_WCSSTR */
 
 /* Define if you have the wcstod function.  */
-#define _GLIBCPP_HAVE_WCSTOD 1
+/* #undef _GLIBCPP_HAVE_WCSTOD */
 
 /* Define if you have the wcstof function.  */
 /* #undef _GLIBCPP_HAVE_WCSTOF */
 
 /* Define if you have the wcstok function.  */
-#define _GLIBCPP_HAVE_WCSTOK 1
+/* #undef _GLIBCPP_HAVE_WCSTOK */
 
 /* Define if you have the wcstol function.  */
-#define _GLIBCPP_HAVE_WCSTOL 1
+/* #undef _GLIBCPP_HAVE_WCSTOL */
 
 /* Define if you have the wcstoul function.  */
-#define _GLIBCPP_HAVE_WCSTOUL 1
+/* #undef _GLIBCPP_HAVE_WCSTOUL */
 
 /* Define if you have the wcsxfrm function.  */
-#define _GLIBCPP_HAVE_WCSXFRM 1
+/* #undef _GLIBCPP_HAVE_WCSXFRM */
 
 /* Define if you have the wctob function.  */
-#define _GLIBCPP_HAVE_WCTOB 1
+/* #undef _GLIBCPP_HAVE_WCTOB */
 
 /* Define if you have the wmemchr function.  */
-#define _GLIBCPP_HAVE_WMEMCHR 1
+/* #undef _GLIBCPP_HAVE_WMEMCHR */
 
 /* Define if you have the wmemcmp function.  */
-#define _GLIBCPP_HAVE_WMEMCMP 1
+/* #undef _GLIBCPP_HAVE_WMEMCMP */
 
 /* Define if you have the wmemcpy function.  */
-#define _GLIBCPP_HAVE_WMEMCPY 1
+/* #undef _GLIBCPP_HAVE_WMEMCPY */
 
 /* Define if you have the wmemmove function.  */
-#define _GLIBCPP_HAVE_WMEMMOVE 1
+/* #undef _GLIBCPP_HAVE_WMEMMOVE */
 
 /* Define if you have the wmemset function.  */
-#define _GLIBCPP_HAVE_WMEMSET 1
+/* #undef _GLIBCPP_HAVE_WMEMSET */
 
 /* Define if you have the wprintf function.  */
 /* #undef _GLIBCPP_HAVE_WPRINTF */
@@ -881,10 +881,10 @@
 #define _GLIBCPP_HAVE_UNISTD_H 1
 
 /* Define if you have the <wchar.h> header file.  */
-#define _GLIBCPP_HAVE_WCHAR_H 1
+/* #undef _GLIBCPP_HAVE_WCHAR_H */
 
 /* Define if you have the <wctype.h> header file.  */
-#define _GLIBCPP_HAVE_WCTYPE_H 1
+/* #undef _GLIBCPP_HAVE_WCTYPE_H */
 
 /* Define if you have the m library (-lm).  */
 #define _GLIBCPP_HAVE_LIBM 1
